@@ -5,6 +5,6 @@ Cache = function() {
   list(keys = keys,
        get = function(key) get(key, envir = ee),
        put = function(key, value) assign(key, value, envir = ee),
-       rm = function(keys) rm(list = intersect(keys, keys()), envir = ee),
+       rm = function(keys) { x = intersect(keys, keys()); rm(list = x, envir = ee); x },
        exists = function(key) exists(key, envir = ee))
 }
